@@ -87,13 +87,7 @@ impl Kubectl {
             object.meta_mut().resource_version = existing.resource_version();
         }
 
-        let pp = self.post_with_manager(&self.manager);
-
-        let object = if object.resource_version().is_some() {
-            self.patch(object, objects).await?
-        } else {
-            objects.create(&pp, &object).await?
-        };
+        let object = self.patch(object, objects).await?;
 
         Ok(object)
     }
@@ -113,13 +107,7 @@ impl Kubectl {
             object.meta_mut().resource_version = existing.resource_version();
         }
 
-        let pp = self.post_with_manager(&self.manager);
-
-        let object = if object.resource_version().is_some() {
-            self.patch(object, objects).await?
-        } else {
-            objects.create(&pp, &object).await?
-        };
+        let object = self.patch(object, objects).await?;
 
         Ok(object)
     }
@@ -138,13 +126,7 @@ impl Kubectl {
             object.meta_mut().resource_version = existing.resource_version();
         }
 
-        let pp = self.post_with_manager(&self.manager);
-
-        let object = if object.resource_version().is_some() {
-            self.patch(object, objects).await?
-        } else {
-            objects.create(&pp, &object).await?
-        };
+        let object = self.patch(object, objects).await?;
 
         Ok(object)
     }
