@@ -23,6 +23,12 @@ impl super::Kubectl {
         api::PostParams::default()
     }
 
+    pub fn post_with_manager(&self, manager: &str) -> api::PostParams {
+        let mut pp = self.post_params();
+        pp.field_manager = Some(manager.to_string());
+        pp
+    }
+
     pub fn patch_params(&self) -> api::PatchParams {
         api::PatchParams::default()
     }
@@ -31,6 +37,17 @@ impl super::Kubectl {
         api::PatchParams::apply(manager)
     }
 
+    pub fn log_params(&self) -> api::LogParams {
+        api::LogParams::default()
+    }
+
+    pub fn log_params_previous(&self) -> api::LogParams {
+        api::LogParams {
+            previous: true,
+            ..api::LogParams::default()
+        }
+    }
+
     pub async fn patch<K>(&self, object: K, api: kube::Api<K>) -> kube::Result<K>
     where
         K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
@@ -38,8 +55,8 @@ impl super::Kubectl {
     {
         let name = object.name();
         let patch = api::Patch::Apply(&object);
-        api.patch(&name, &self.patch_with_manager(&self.manager), &patch)
-            .await
+        let pp = self.patch_with_manager(&self.manager);
+        api.patch(&name, &pp, &patch).await
     }
 
     pub fn api<T>(&self) -> api::Api<T>
